# prompt_version_manager

[![PyPI version](https://img.shields.io/pypi/v/prompt_version_manager.svg)](https://pypi.org/project/prompt_version_manager/)  
[![License](https://img.shields.io/github/license/parthrangarajan/prompt_version_manager.svg)](LICENSE)

A lightweight Python package to automatically track and save changes to a `prompt` variable with timestamps and optional outputs in a JSON file (`prompt_version_manager.json`).

## Features

- Automatically saves every change to your `prompt` variable with time.
- Stores optional output related to the prompt.
- Saves prompt history in a single JSON file.
- Simple API using Python properties.

## Installation

You can install the package directly from PyPI:

